@@ -460,6 +460,7 @@ class List(Protobj):
 
         self = cls.__new__(cls)
         self.list = list[:]
+        return self
 
 
 class OffsetMap(object):
@@ -759,13 +760,13 @@ def pack_list(from_, pack_type):
 
     if isinstance(pack_type, six.string_types):
         return struct.pack("=" + pack_type * len(from_), *from_)
-    elif hasattr(pack_type, "synthetic"):
-        return pack_type.synthetic(*from_).pack()
     else:
         buf = six.BytesIO()
         for item in from_:
-            # If we can't pack it, you'd better have packed it yourself...
-            if isinstance(item, Struct):
+            # If we can't pack it, you'd better have packed it yourself. But
+            # let's not confuse things which aren't our Probobjs for packable
+            # things.
+            if isinstance(item, Protobj) and hasattr(item, "pack"):
                 buf.write(item.pack())
             else:
                 buf.write(item)
